CellsResponse class

A class that represents the response from the getCellInfo method.

Constructors

CellsResponse({List<CellType>? neighboringCellList, List<CellType>? primaryCellList, List<CellDataList>? cellDataList})
CellsResponse.fromDynamic(dynamic json)
Constructs a CellsResponse object from a dynamic object.
CellsResponse.fromJson(Map<String, dynamic> json)
Constructs a CellsResponse object from a JSON object.

Properties

cellDataList ↔ List<CellDataList>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
neighboringCellList ↔ List<CellType>?
getter/setter pair
primaryCellList ↔ List<CellType>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts a CellsResponse object to a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited