CellDataList class

Model describing CellDataList data exchanged with the native plugin.

Constructors

CellDataList({double? latitude, double? longitude, String? type, int? dbm})
CellDataList.fromJson(Map<String, dynamic> json)
Creates a CellDataList from a decoded JSON Map.

Properties

dbm ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latitude ↔ double?
getter/setter pair
longitude ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this CellDataList into a JSON-serializable Map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited