Network class

Model describing Network data exchanged with the native plugin.

Constructors

Network({String? iso, String? mcc, String? mnc})
Network.fromJson(Map<String, dynamic> json)
Creates a Network from a decoded JSON Map.

Properties

hashCode → int
The hash code for this object.
no setterinherited
iso ↔ String?
getter/setter pair
mcc ↔ String?
getter/setter pair
mnc ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this Network into a JSON-serializable Map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited