Wcdma class

Model describing Wcdma data exchanged with the native plugin.

Constructors

Wcdma({BandWCDMA? bandWCDMA, SignalWCDMA? signalWCDMA, String? connectionStatus, Network? network, int? ci, int? lac, int? psc, int? cid, int? rnc, String? cgi, String? type})
Wcdma.fromJson(Map<String, dynamic> json)
Creates a Wcdma from a decoded JSON Map.

Properties

bandWCDMA BandWCDMA?
getter/setter pair
cgi String?
getter/setter pair
ci int?
getter/setter pair
cid int?
getter/setter pair
connectionStatus String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lac int?
getter/setter pair
network Network?
getter/setter pair
psc int?
getter/setter pair
rnc int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalWCDMA SignalWCDMA?
getter/setter pair
type String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this Wcdma into a JSON-serializable Map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited